(function() {
  var assert, express, minirpc, rpc, server, x;
  require('coffee-script');
  express = require('express');
  minirpc = require('../lib/minirpc');
  assert = require('assert');
  x = exports;
  server = express.createServer();
  server.get('/', function(req, res) {
    return res.send('Hello World');
  });
  rpc = new minirpc.RPC;
  server.use(rpc._middleware());
  rpc.sum = function(a, b) {
    return a + b;
  };
  rpc.get_header = function(header_name) {
    return rpc._request.headers[header_name];
  };
  x.test_server_1 = function() {
    return assert.response(server, {
      url: '/',
      method: 'GET'
    }, function(res) {
      return assert.equal(res.body, 'Hello World');
    });
  };
  x.test_rpc_javascript_stub_delivery = function() {
    return assert.response(server, {
      url: '/___minirpc.js',
      method: 'GET'
    }, function(res) {
      assert.equal(res.statusCode, 200);
      return assert.equal(res.headers['content-type'], 'application/javascript');
    });
  };
  x.test_execute = function() {
    return minirpc.execute(rpc, {
      method: 'sum',
      params: [1, 2]
    }, function(res, err) {
      return assert.equal(res, 3);
    });
  };
  x.test_simple_rpc_call = function() {
    return assert.response(server, {
      url: '/___minirpc',
      method: 'POST',
      data: '{"jsonrpc": "2.0", "method": "sum", "params": [1, 2], "id": 1}',
      headers: {
        'Content-Type': 'application/json; charset=utf8'
      }
    }, function(res) {
      var obj;
      assert.equal(res.statusCode, 200);
      assert.equal(res.headers['content-type'], 'application/json');
      obj = JSON.parse(res.body);
      assert.equal(obj.result, 3);
      assert.equal(obj.error, null);
      return assert.equal(obj.id, 1);
    });
  };
  x.test_rpc_call_accessing_request = function() {
    return assert.response(server, {
      url: '/___minirpc',
      method: 'POST',
      data: '{"jsonrpc": "2.0", "method": "get_header", "params": ["foo"], "id": 1}',
      headers: {
        'Content-Type': 'application/json; charset=utf8',
        'foo': 'bar'
      }
    }, function(res) {
      var obj;
      assert.equal(res.statusCode, 200);
      assert.equal(res.headers['content-type'], 'application/json');
      obj = JSON.parse(res.body);
      assert.equal(obj.result, 'bar');
      assert.equal(obj.error, null);
      return assert.equal(obj.id, 1);
    });
  };
}).call(this);
